@@ -1,5 +1,5 @@
 /***************************************************************************
-**    xFrame.cpp  $Revision: 1.9 $ - $Name: V2-05 $ 
+**    xFrame.cpp  $Revision: 1.12 $ - $Name: V2-18 $ 
 **    Self fitting Frame class
 **
 **    Copyright (C) 1996 Joseph Croft <jcroft@unicomp.net>
@@ -23,8 +23,8 @@
 #include <string.h>
 #include <qkeycode.h>
 #include <qsize.h>
-#include "xFrame.h"
 #include "xTable.h"
+#include "xFrame.h"
 
 static int dbg = 0;
 
@@ -69,6 +69,7 @@ xFrame::xFrame(xWidgetResInfo *pPRes, QWidget *pParent, const char *pName) :
    widgetCount = 0;
    fitFrameRecurse = 0;
    setAcceptFocus(TRUE);
+   fitted = FALSE;
    if (dbg) fprintf(stdout, "xFrame::xFrame():Exit\n");
    if (dbg) fflush(stdout);
 }
@@ -95,6 +96,7 @@ xFrame::xFrame(xWidgetResInfo *pPRes, int align, int resz, int space,
    widgetCount = 0;
    fitFrameRecurse = 0;
    setAcceptFocus(TRUE);
+   fitted = FALSE;
    if (dbg) fprintf(stdout, "xFrame::xFrame():Exit\n");
 }
 
@@ -116,6 +118,7 @@ void xFrame::coupleWidgets(QWidget *pWdt1, QWidget *pWdt2, int side)
       couplings.insert(pWdt1->name(), new xWdtSpec(pWdt2, side));
    else
       fprintf(stderr, "xFrame::coupleWidgets: Unnamed Widgets cannot be coupled\n");
+   fitted = FALSE;
    if (dbg) fprintf(stdout, "xFrame::coupleWidgets():Exit\n");
    if (dbg) fflush(stdout);
 }
@@ -155,6 +158,7 @@ int xFrame::addWidget(QWidget *pWidget, QWidget *pNeighbor, int relativePos)
    if (dbg) fflush(stdout);
    if (dbg) fprintf(stdout, "xFrame::addWdiget(%s:%s):Exit, fc = %d\n", pWidget->className(), pWidget->name(), fc);
    if (dbg) fflush(stdout);
+   fitted = FALSE;
    return(rv);
 }
 
@@ -188,7 +192,7 @@ void xFrame::resize(QSize *frameSize)
    if (dbg) fflush(stdout);
 }
 
-void xFrame::fitFrame(const QSize *frameSize)
+void xFrame::fitFrame(const QSize *frameSize, bool force)
 {
    int maxSize = 0, offset, totalSize = 0, currentSize;
    int frameH = 0, frameW = 0, offsetV, offsetH;
@@ -218,7 +222,7 @@ void xFrame::fitFrame(const QSize *frameSize)
    if (widgetEqualize > 1)
       widgetEqualize = 0;
 */
-   if (fc > 1)
+   if (force != TRUE && (fc > 1 || fitted == TRUE))
    {
 /*
       if (dbg) fprintf(stdout, "xFrame::fitFram(%s:%s):Algn = %x\n", className(), name(), widgetAlgn);
@@ -606,6 +610,7 @@ void xFrame::fitFrame(const QSize *frameSize)
             offset += x2;
          else
             offset += widgetSpac;
+         fitted = TRUE;
       }
    }
 //   fitFrameRecurse--;
