@@ -1,5 +1,5 @@
 /***************************************************************************
-**    xMultiLinWin.cpp  $Revision: 1.11 $ - $Name: V2-05 $ 
+**    xMultiLinWin.cpp  $Revision: 1.13 $ - $Name: V2-18 $ 
 **    QWidget for manipulating Multiple lines of text in a window
 **
 **    Copyright (C) 1996 Joseph Croft <jcroft@unicomp.net>
@@ -193,6 +193,22 @@ void xMultiLineWin::scrollWindow(int lines)
    scrollWindowImage(botLineOfs - x);
 }
 
+void xMultiLineWin::scrollToLine(int line)
+{
+   int x;
+
+   if (dbg) fprintf(stdout, "MultiLineWin::scrollToLine():Enter, line = %d\n", line);
+   if (dbg) fflush(stdout);
+   if (dbg) fprintf(stdout, "MultiLineWin::scrollToLine():botLineOfs = %d\n", botLineOfs);
+   if (dbg) fflush(stdout);
+   x = line - (botLineOfs - windowHeight);
+   if (dbg) fprintf(stdout, "MultiLineWin::scrollToLine():x = %d\n", x);
+   if (dbg) fflush(stdout);
+   scrollWindow(x);
+   if (dbg) fprintf(stdout, "MultiLineWin::scrollToLine(%d):Exit\n", line);
+   if (dbg) fflush(stdout);
+}
+
 void xMultiLineWin::updateImage(int lines)
 {
    QFontMetrics fm = QWidget::fontMetrics();
@@ -429,13 +445,23 @@ void xMultiLineWin::mouseDoubleClickEvent(QMouseEvent *pEvt)
                p.setFont(fnt);
                continue;
             }
-            else if ((isalnum(*cp) || *cp == '_') && inspace == TRUE)
+            else if ((isalnum(*cp) || 
+                     *cp == '~' ||
+                     *cp == '-' ||
+                     *cp == '^' ||
+                     *cp == '`' ||
+                     *cp == '_') && inspace == TRUE)
             {
                pWord = cp;
                if (dbg) fprintf(stdout, "MultiLineWin::doubleClickEvent():At Start of Word |%s|\n", pWord);
                inspace = FALSE;
             }
-            else if (inspace == FALSE && !isalnum(*cp) && *cp != '_')
+            else if (inspace == FALSE && !isalnum(*cp) && 
+                                         *cp != '~' &&
+                                         *cp != '-' &&
+                                         *cp != '^' &&
+                                         *cp != '`' &&
+                                         *cp != '_')
             {
                if (dbg) fprintf(stdout, "MultiLineWin::doubleClickEvent():In Space |%s|\n", cp);
                inspace = TRUE;
@@ -445,7 +471,13 @@ void xMultiLineWin::mouseDoubleClickEvent(QMouseEvent *pEvt)
                 pEvt->pos().x() <= y + p.fontMetrics().width(*cp))
             {
                if (dbg) fprintf(stdout, "MultiLineWin::doubleClickEvent():Found Word!!!\n");
-               for (strWord = ""; isalnum(*pWord) || *pWord == '_'; pWord++)
+               for (strWord = ""; isalnum(*pWord) || 
+                                  *pWord == '~' ||
+                                  *pWord == '-' ||
+                                  *pWord == '^' ||
+                                  *pWord == '`' ||
+                                  *pWord == '_'; 
+                                  pWord++)
                   strWord += *pWord;
                if (dbg) fprintf(stdout, "MultiLineWin::doubleClickEvent():The Selected Word is |%s|\n",
                                 (const char *)strWord);
