@@ -1,5 +1,5 @@
 /***************************************************************************
-**    xSQLBase.cpp  $Revision: 1.11 $ - $Name: V2-05 $ 
+**    xSQLBase.cpp  $Revision: 1.16 $ - $Name: V2-18 $ 
 **    SQL View frame
 **
 **    Copyright (C) 1996 Joseph Croft <jcroft@unicomp.net>
@@ -23,13 +23,13 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <qlist.h>
-#include <qmsgbox.h>
 #include <qobject.h>
 #include <qlined.h>
 #include <qlabel.h>
 #include <qobjcoll.h>
 #include "xEdit.h"
 #include "xMisc.h"
+#include "xMessageBox.h"
 #include "xSQLField.h"
 #include "xSQLIndex.h"
 #include "xSQLBase.h"
@@ -55,7 +55,7 @@ xSQLBase::xSQLBase(xSQLFieldDef *pFields)
       if (dbg) fprintf(stdout, "xSQLBase::xSQLBase:Have field: Name: |%s|, Label: |%s|, Link: |%s|, Type: %d\n",
                                fp->name, fp->label, fp->link, fp->type);
       if (dbg) fflush(stdout);
-      if ((fp->type & sqlComputation) == 0)
+      if ((fp->type & ~sqlHidden) != sqlComputation)
       {
          if (dbg) fprintf(stdout, "xSQLBase::xSQLBase:Adding field to fieldNames\n");
          if (dbg) fflush(stdout);
@@ -98,35 +98,42 @@ xSQLBase::~xSQLBase()
 
 bool xSQLBase::query(int db, QList<QString> sort)
 {
-   QDict<QString> links, match;
-   return(query(db, match, links, sort));
+   QDict<QString> links, match, skip;
+   return(query(db, match, links, skip, sort));
 }
 
 bool xSQLBase::query(int db, QString index, QList<QString> sort)
 {
-   QDict<QString> links, match;
+   QDict<QString> links, match, skip;
    QString indexName;
 
    indexName = getPriTable() + ".index";
    links.setAutoDelete(TRUE);
    links.insert((const char *)indexName, new QString(index));
-   return(query(db, match, links, sort));
+   return(query(db, match, links, skip, sort));
 }
 
 bool xSQLBase::query(int db, long index, QList<QString> sort)
 {
-   QDict<QString> links, match;
+   QDict<QString> links, match, skip;
    QString indexName, strIndex;
 
    indexName = getPriTable() + ".index";
    strIndex.setNum(index);
    links.setAutoDelete(TRUE);
    links.insert((const char *)indexName, new QString(strIndex));
-   return(query(db, match, links, sort));
+   return(query(db, match, links, skip, sort));
 }
 
 bool xSQLBase::query(int db, QDict<QString> &match, QDict<QString> &links, 
                      QList<QString> sort)
+{
+   QDict<QString> skip;
+   return(query(db, match, links, skip, sort));
+}
+
+bool xSQLBase::query(int db, QDict<QString> &match, QDict<QString> &links, 
+                     QDict<QString> &skip, QList<QString> sort)
 {
    QString strQuery, strIndexName;
    const char *ccp;
@@ -197,7 +204,7 @@ bool xSQLBase::query(int db, QDict<QString> &match, QDict<QString> &links,
             x++;
             strQuery += dataIt.currentKey();
             strQuery += " like '%";
-            strQuery += *dataIt.current();
+            strQuery += escString(*dataIt.current());
             strQuery += "%'";
             if (dbg) fprintf(stdout, "xSQLBase::query():3.strQuery = |%s|\n",
                                       (const char *)strQuery);
@@ -206,8 +213,47 @@ bool xSQLBase::query(int db, QDict<QString> &match, QDict<QString> &links,
       }
    }
       
-   if (dbg) fprintf(stdout, "xSQLBase::query():Adding in %d Links\n",
-                             links.count());
+   if (dbg) fprintf(stdout, "xSQLBase::query():Adding in %d Skips\n",
+                             skip.count());
+   if (dbg)
+   {
+      QDictIterator<QString> it(skip);
+      fprintf(stdout, "xSQLBase::query():Skip Count = %d\n",
+                      skip.count());
+      for (int x1 = 0; it.current(); ++it, x1++)
+      {
+         fprintf(stdout, "xSQLBase::query():link %d: |%s:%s|\n", x1,
+                         it.currentKey(),
+                         (const char *)escString(*it.current()));
+      }
+      if (dbg) fflush(stdout);
+   }
+
+   if (skip.count() > 0)
+   {
+      if (dbg) fflush(stdout);
+      QDictIterator<QString> skipIt(skip);
+      for (; skipIt.current(); ++skipIt)
+      {
+         if (dbg) fprintf(stdout, "xSQLBase::query():Found |%s|:|%s|\n",
+                                   skipIt.currentKey(),
+                                   (const char *)escString(*skipIt.current()));
+         if (dbg) fflush(stdout);
+         if (x > 0)
+            strQuery += " AND ";
+         else
+            strQuery += " WHERE ";
+         x++;
+         strQuery += skipIt.currentKey();
+         strQuery += " <> '";
+         strQuery += escString(*skipIt.current());
+         strQuery += "'";
+         if (dbg) fprintf(stdout, "xSQLBase::query():4.strQuery = |%s|\n",
+                                   (const char *)strQuery);
+         if (dbg) fflush(stdout);
+      }
+   }
+
    if (dbg)
    {
       QDictIterator<QString> it(links);
@@ -217,7 +263,7 @@ bool xSQLBase::query(int db, QDict<QString> &match, QDict<QString> &links,
       {
          fprintf(stdout, "xSQLBase::query():link %d: |%s:%s|\n", x1,
                          it.currentKey(),
-                         (const char *)*it.current());
+                         (const char *)escString(*it.current()));
       }
       if (dbg) fflush(stdout);
    }
@@ -230,7 +276,7 @@ bool xSQLBase::query(int db, QDict<QString> &match, QDict<QString> &links,
       {
          if (dbg) fprintf(stdout, "xSQLBase::query():Found |%s|:|%s|\n",
                                    linksIt.currentKey(),
-                                   (const char *)*linksIt.current());
+                                   (const char *)escString(*linksIt.current()));
          if (dbg) fflush(stdout);
          if (x > 0)
             strQuery += " AND ";
@@ -239,7 +285,7 @@ bool xSQLBase::query(int db, QDict<QString> &match, QDict<QString> &links,
          x++;
          strQuery += linksIt.currentKey();
          strQuery += " = '";
-         strQuery += *linksIt.current();
+         strQuery += escString(*linksIt.current());
          strQuery += "'";
          if (dbg) fprintf(stdout, "xSQLBase::query():4.strQuery = |%s|\n",
                                    (const char *)strQuery);
@@ -256,7 +302,7 @@ bool xSQLBase::query(int db, QDict<QString> &match, QDict<QString> &links,
       {
          fprintf(stdout, "xSQLBase::query():link %d: |%s:%s|\n", x1,
                          it.currentKey(),
-                         (const char *)*it.current());
+                         (const char *)escString(*it.current()));
       }
       if (dbg) fflush(stdout);
    }
@@ -269,7 +315,7 @@ bool xSQLBase::query(int db, QDict<QString> &match, QDict<QString> &links,
       {
          if (dbg) fprintf(stdout, "xSQLBase::query():Adding Field link |%s|:|%s|\n",
                                    linksIt.currentKey(),
-                                   (const char *)*linksIt.current());
+                                   (const char *)escString(*linksIt.current()));
          if (dbg) fflush(stdout);
          if (x > 0)
             strQuery += " AND ";
@@ -279,7 +325,7 @@ bool xSQLBase::query(int db, QDict<QString> &match, QDict<QString> &links,
          strQuery += getTableName(linksIt.currentKey());
          strQuery += ".index";
          strQuery += " = ";
-         strQuery += *linksIt.current();
+         strQuery += escString(*linksIt.current());
          if (dbg) fprintf(stdout, "xSQLBase::query():5.strQuery = |%s|\n",
                                    (const char *)strQuery);
          if (dbg) fflush(stdout);
@@ -313,7 +359,7 @@ bool xSQLBase::query(int db, QDict<QString> &match, QDict<QString> &links,
    {
       if (dbg) fprintf(stdout, "xSQLBase::query():Query Failed!!!\n");
       if (dbg) fflush(stdout);
-      QMessageBox::message("Query Error", msqlErrMsg, "Ok");
+      xMessageBox::message("Query Error", msqlErrMsg, "Ok");
       prevQuery = "";
       pViewData = NULL;
       rv = FALSE;
@@ -331,6 +377,158 @@ bool xSQLBase::query(int db, QDict<QString> &match, QDict<QString> &links,
    return(rv);
 }
 
+bool xSQLBase::del(int db, QString index)
+{
+   QDict<QString> links, match;
+   QString indexName;
+
+   indexName = getPriTable() + ".index";
+   links.setAutoDelete(TRUE);
+   links.insert((const char *)indexName, new QString(index));
+   return(del(db, match, links));
+}
+
+bool xSQLBase::del(int db, long index)
+{
+   QDict<QString> links, match;
+   QString indexName, strIndex;
+
+   indexName = getPriTable() + ".index";
+   strIndex.setNum(index);
+   links.setAutoDelete(TRUE);
+   links.insert((const char *)indexName, new QString(strIndex));
+   return(del(db, match, links));
+}
+
+bool xSQLBase::del(int db, QDict<QString> &match, QDict<QString> &links) 
+{
+   QString strQuery, strIndexName;
+   const char *ccp;
+   int x;
+   bool rv;
+
+   if (dbg) fprintf(stdout, "xSQLBase::delete(QDict):Enter\n");
+   if (dbg) fflush(stdout);
+   if (pViewData)
+      msqlFreeResult(pViewData);
+
+   strQuery = "DELETE FROM ";
+
+   //
+   // Add in the tablename
+   //
+   strQuery += getPriTable();
+
+   x = 0;
+   if (dbg) fprintf(stdout, "xSQLBase::delete():Adding in %d Matches\n",
+                             links.count());
+   if (match.count() > 0)
+   {
+      QDictIterator<QString> dataIt(match);
+      for (; dataIt.current(); ++dataIt)
+      {
+         if (strcmp(getTableName(dataIt.currentKey()), getPriTable()) != 0)
+         {
+            if (dbg) fprintf(stdout, "xSQLBase::delete():Skipping Field |%s|\n",
+                                     dataIt.currentKey());
+            continue;
+         }
+
+         if (dbg) fprintf(stdout, "xSQLBase::delete():Field |%s| has |%s|\n",
+                                  dataIt.currentKey(),
+                                  (const char *)escString(*dataIt.current()));
+         if (strlen((const char *)*dataIt.current()) > 0)
+         {
+            if (x > 0)
+               strQuery += " AND ";
+            else
+               strQuery += " WHERE ";
+            x++;
+            strQuery += dataIt.currentKey();
+            strQuery += " like '%";
+            strQuery += escString(*dataIt.current());
+            strQuery += "%'";
+            if (dbg) fprintf(stdout, "xSQLBase::delete():3.strQuery = |%s|\n",
+                                      (const char *)strQuery);
+            if (dbg) fflush(stdout);
+         }
+      }
+   }
+      
+   if (dbg) fprintf(stdout, "xSQLBase::delete():Adding in %d Links\n",
+                             links.count());
+   if (dbg)
+   {
+      QDictIterator<QString> it(links);
+      fprintf(stdout, "xSQLBase::delete():Link Count = %d\n",
+                      links.count());
+      for (int x1 = 0; it.current(); ++it, x1++)
+      {
+         fprintf(stdout, "xSQLBase::delete():link %d: |%s:%s|\n", x1,
+                         it.currentKey(),
+                         (const char *)escString(*it.current()));
+      }
+      if (dbg) fflush(stdout);
+   }
+
+   if (links.count() > 0)
+   {
+      if (dbg) fflush(stdout);
+      QDictIterator<QString> linksIt(links);
+      for (; linksIt.current(); ++linksIt)
+      {
+         if (strcmp(getTableName(linksIt.currentKey()), getPriTable()) != 0)
+         {
+            if (dbg) fprintf(stdout, "xSQLBase::delete():Skipping Field |%s|\n",
+                                     linksIt.currentKey());
+            continue;
+         }
+
+         if (dbg) fprintf(stdout, "xSQLBase::delete():Found |%s|:|%s|\n",
+                                   linksIt.currentKey(),
+                                   (const char *)escString(*linksIt.current()));
+         if (dbg) fflush(stdout);
+         if (x > 0)
+            strQuery += " AND ";
+         else
+            strQuery += " WHERE ";
+         x++;
+         strQuery += linksIt.currentKey();
+         strQuery += " = '";
+         strQuery += escString(*linksIt.current());
+         strQuery += "'";
+         if (dbg) fprintf(stdout, "xSQLBase::delete():4.strQuery = |%s|\n",
+                                   (const char *)strQuery);
+         if (dbg) fflush(stdout);
+      }
+   }
+
+   ccp = strQuery;
+   if (dbg) fprintf(stdout, "xSQLBase::delete():Final strQuery = |%s|\n", ccp);
+   if (dbg) fflush(stdout);
+
+   if (msqlQuery(db, (char *)ccp) < 0)
+   {
+      if (dbg) fprintf(stdout, "xSQLBase::delete():Query Failed!!!\n");
+      if (dbg) fflush(stdout);
+      xMessageBox::message("Query Error", msqlErrMsg, "Ok");
+      prevQuery = "";
+      pViewData = NULL;
+      rv = FALSE;
+   }
+   else
+   {
+      if (dbg) fprintf(stdout, "xSQLBase::delete():Query Success!!!\n");
+      if (dbg) fflush(stdout);
+      prevQuery = strQuery;
+      pViewData = msqlStoreResult();
+      rv = TRUE;
+   }
+   if (dbg) fprintf(stdout, "xSQLBase::delete():Exit(%d)\n", rv);
+   if (dbg) fflush(stdout);
+   return(rv);
+}
+
 long xSQLBase::insert(int db, QDict<QString> &fields)
 {
    QList<QString> tables;
@@ -360,7 +558,7 @@ long xSQLBase::insert(int db, QDict<QString> &fields)
    {
       if (dbg) fprintf(stdout, "xSQLBase::insert():3.Next Field: Field:|%s|, Data:|%s|\n",
                                 dataIt.currentKey(),
-                                (const char *)*dataIt.current());
+                                (const char *)escString(*dataIt.current()));
 
       if (calcFields[dataIt.currentKey()] != NULL)
       {
@@ -395,13 +593,13 @@ long xSQLBase::insert(int db, QDict<QString> &fields)
    {
       if (dbg) fprintf(stdout, "xSQLBase::insert():3.Next Field: Field:|%s|, Data:|%s|\n",
                                 dataIt.currentKey(),
-                                (const char *)*dataIt.current());
+                                (const char *)escString(*dataIt.current()));
       if (strlen((const char *)*dataIt.current()) > 0)
       {
          if (x > 0)
             query += ", ";
          query += " '";
-         query += dataIt.current()->stripWhiteSpace();
+         query += escString(dataIt.current()->stripWhiteSpace());
          query += "'";
          if (dbg) fprintf(stdout, "xSQLBase::insert():3.query = |%s|\n",
                                    (const char *)query);
@@ -420,7 +618,7 @@ long xSQLBase::insert(int db, QDict<QString> &fields)
       
       if (dbg) fprintf(stdout, "xSQLBase::insert():Query Failed!!!\n");
       if (dbg) fflush(stdout);
-      QMessageBox::message("Insert Error", msqlErrMsg, "Ok");
+      xMessageBox::message("Insert Error", msqlErrMsg, "Ok");
       rv = -1;
    }
    else
@@ -484,7 +682,7 @@ bool xSQLBase::update(int db, QDict<QString> &fields, QDict<QString> &links)
    {
       if (dbg) fprintf(stdout, "xSQLBase::update():3.Next Field: Field:|%s|, Data:|%s|\n",
                                 dataIt.currentKey(),
-                                (const char *)*dataIt.current());
+                                (const char *)escString(*dataIt.current()));
 
       if (calcFields[dataIt.currentKey()] != NULL)
       {
@@ -503,20 +701,20 @@ bool xSQLBase::update(int db, QDict<QString> &fields, QDict<QString> &links)
          continue;
       }
 
-      if (strlen((const char *)*dataIt.current()) > 0)
-      {
+//      if (strlen((const char *)*dataIt.current()) > 0)
+//      {
          if (x > 0)
             query += ", ";
          query += getFieldName(dataIt.currentKey());
          query += " = '";
-         query += dataIt.current()->stripWhiteSpace();
+         query += escString(dataIt.current()->stripWhiteSpace());
          query += "'";
          if (dbg) fprintf(stdout, "xSQLBase::update():3.query = |%s|\n",
                                    (const char *)query);
          if (dbg) fflush(stdout);
-      }
-      else
-         x--;
+//      }
+//      else
+//         x--;
    }
       
    if (dbg)
@@ -524,11 +722,13 @@ bool xSQLBase::update(int db, QDict<QString> &fields, QDict<QString> &links)
       QDictIterator<QString> it(links);
       fprintf(stdout, "xSQLBase::doQuery():Link Count = %d\n",
                       links.count());
+      if (dbg) fflush(stdout);
       for (int x1 = 0; it.current(); ++it, x1++)
       {
          fprintf(stdout, "xSQLBase::doQuery():link %d: |%s:%s|\n", x1,
                          it.currentKey(),
-                         (const char *)*it.current());
+                         (const char *)escString(*it.current()));
+         if (dbg) fflush(stdout);
       }
       if (dbg) fflush(stdout);
    }
@@ -544,7 +744,7 @@ bool xSQLBase::update(int db, QDict<QString> &fields, QDict<QString> &links)
             query += " WHERE ";
          query += linksIt.currentKey();
          query += " = '";
-         query += *linksIt.current();
+         query += escString(*linksIt.current());
          query += "'";
          if (dbg) fprintf(stdout, "xSQLBase::update():4.query = |%s|\n",
                                    (const char *)query);
@@ -557,11 +757,13 @@ bool xSQLBase::update(int db, QDict<QString> &fields, QDict<QString> &links)
       QDictIterator<QString> it(fieldLinks);
       fprintf(stdout, "xSQLBase::update():Field Link Count = %d\n",
                       fieldLinks.count());
+      if (dbg) fflush(stdout);
       for (int x1 = 0; it.current(); ++it, x1++)
       {
          fprintf(stdout, "xSQLBase::update():link %d: |%s:%s|\n", x1,
                          it.currentKey(),
                          (const char *)*it.current());
+         if (dbg) fflush(stdout);
       }
       if (dbg) fflush(stdout);
    }
@@ -576,6 +778,7 @@ bool xSQLBase::update(int db, QDict<QString> &fields, QDict<QString> &links)
          {
             if (dbg) fprintf(stdout, "xSQLBase::update():Field:|%s| is not of primary table!\n",
                                      linksIt.currentKey());
+            if (dbg) fflush(stdout);
             x--;
             continue;
          }
@@ -586,7 +789,7 @@ bool xSQLBase::update(int db, QDict<QString> &fields, QDict<QString> &links)
             query += " WHERE ";
          query += linksIt.currentKey();
          query += " = ";
-         query += *linksIt.current();
+         query += escString(*linksIt.current());
          if (dbg) fprintf(stdout, "xSQLBase::update():4.query = |%s|\n",
                                    (const char *)query);
          if (dbg) fflush(stdout);
@@ -602,7 +805,7 @@ bool xSQLBase::update(int db, QDict<QString> &fields, QDict<QString> &links)
       
       if (dbg) fprintf(stdout, "xSQLBase::update():Query Failed!!!\n");
       if (dbg) fflush(stdout);
-      QMessageBox::message("Update Error", msqlErrMsg, "Ok");
+      xMessageBox::message("Update Error", msqlErrMsg, "Ok");
       rv = FALSE;
    }
    else
@@ -951,4 +1154,22 @@ QString xSQLBase::calcField(QDict<QString> &fields, const char *pName,
    return(rv);
 }
 
+QString xSQLBase::escString(const char *pStr)
+{
+   QString rv;
 
+   for (; pStr != NULL && *pStr; pStr++)
+   {
+      switch(*pStr)
+      {
+         case '\?':
+         case '\%':
+         case '\\':
+         case '\'':
+            rv += '\\';
+            break;
+      }
+      rv += *pStr;
+   }
+   return(rv);
+}
