@@ -1,5 +1,5 @@
 /***************************************************************************
-**    xSQLTable.cpp  $Revision: 1.14 $ - $Name: V2-05 $ 
+**    xSQLTable.cpp  $Revision: 1.20 $ - $Name: V2-18 $ 
 **    SQL View frame
 **
 **    Copyright (C) 1996 Joseph Croft <jcroft@unicomp.net>
@@ -21,10 +21,10 @@
  ***************************************************************************/
 #include <stdio.h>
 #include <qlist.h>
-#include <qmsgbox.h>
 #include <qobjcoll.h>
 #include "xEdit.h"
 #include "xLabel.h"
+#include "xMessageBox.h"
 #include "xSQLTable.h"
 
 static int dbg = 0;
@@ -34,7 +34,7 @@ xSQLTable::xSQLTable(xWidgetResInfo *pPRes, QWidget *pParent,
                      const char *pTitleStr, int rows) :
           xFrame((wdtRes = new xWidgetResInfo(pPRes, QString(""),
                                               QString(""))),
-                  xALIGN_Vert, xSPACE_ToFit, 0, pParent, pName),
+                  xALIGN_Vert, xSPACE_Resize, 0, pParent, pName),
           xSQLBase(pFields)
 {
    QFontMetrics fm(fontMetrics());
@@ -52,15 +52,16 @@ xSQLTable::xSQLTable(xWidgetResInfo *pPRes, QWidget *pParent,
    curRow = 1;
    insMode = FALSE;
    insRow = -1;
+   connected = FALSE;
    setFrameStyle(QFrame::Panel | QFrame::Raised);
    setMargins(0, 0);
 
-   pFrame = new xFrame(wdtRes, xALIGN_Vert, xSPACE_ToFit, 0, this, "FieldFrame");
+   pFrame = new xFrame(wdtRes, xALIGN_Vert, xSPACE_Resize, 0, this, "FieldFrame");
    pFrame->setMargins(0, 0);
 
    for (pf = pFields, cols = 0; pf->name != NULL; pf++)
    {
-      if (pf->type != sqlHidden)
+      if ((pf->type & sqlHidden) == 0)
          cols++;
    }
 
@@ -212,6 +213,14 @@ bool xSQLTable::query(int db, QDict<QString> &match, QDict<QString> &links,
    return(rv);
 }
 
+bool xSQLTable::query(int db, QDict<QString> &match, QDict<QString> &links,
+                      QDict<QString> &skip, QList<QString> sort)
+{
+   bool rv = xSQLBase::query(db, match, links, skip, sort);
+   setSB();
+   return(rv);
+}
+
 QDict<QString> xSQLTable::getRow()
 {
    if (dbg) fprintf(stdout, "xSQLTable::getSelectedRow():Enter/Exit():selRow = %d\n",
@@ -528,7 +537,7 @@ QString xSQLTable::getField(const char *pFieldName, bool editFirst = TRUE)
    return(rv);
 }
 
-QDict<QString> xSQLTable::getEditFields()
+QDict<QString> xSQLTable::getEditFields(bool blankFields)
 {
    QDict<QString> rv(71);
    xSQLField *pField;
@@ -544,8 +553,8 @@ QDict<QString> xSQLTable::getEditFields()
       if (dbg) fflush(stdout);
       pField = (xSQLField *)pFieldTable->getWidget(c, row);
       if (pField != NULL && 
-          pField->text() != NULL &&
-          strlen(pField->text()) > 0)
+          (blankFields == TRUE ||
+          (pField->text() != NULL && strlen(pField->text()) > 0)))
       {
          pStr = new QString(pField->text());
          if (dbg) fprintf(stdout, "xSQLTable::getEditFields():Adding field:%s |%s|\n",
@@ -863,19 +872,24 @@ void xSQLTable::scrollPageFwd()
 
 void xSQLTable::setSB()
 {
-   if (xSQLBase::rows() + enableMargin > pFieldTable->rows())
+   if (connected && xSQLBase::rows() + enableMargin > pFieldTable->rows())
    {
       pSB->setValue(0);
       pSB->setRange(0, (xSQLBase::rows() + enableMargin) - 
                        pFieldTable->rows());
       pSB->setSteps(1, pFieldTable->rows());
-      connect(pSB, SIGNAL(valueChanged(int)),
-              this, SLOT(scroll(int)));
+      if (!connected)
+      {
+         connect(pSB, SIGNAL(valueChanged(int)),
+                 this, SLOT(scroll(int)));
+      }
+      connected = TRUE;
    }
    else
    {
       disconnect(pSB, SIGNAL(valueChanged(int)),
                  this, SLOT(scroll(int)));
+      connected = FALSE;
    }
    selRow = 1;
 }
@@ -911,7 +925,7 @@ void xSQLTable::haveNewData(xSQLField* pField)
       if (dbg) fprintf(stdout, "xSQLTable::haveNewData():have error from field |%s|\n",
                                 (const char*)errField);
       if (dbg) fflush(stdout);
-      getWidget(errField)->setFocus();
+//      getWidget(errField)->setFocus();
       if (dbg) fprintf(stdout, "xSQLTable::haveNewData():Emitting invalidEntry()\n");
       if (dbg) fflush(stdout);
       emit invalidEntry(getWidget(errField));
@@ -926,9 +940,9 @@ void xSQLTable::haveInvalidEntry(xSQLField *pField)
 
    if (dbg) fprintf(stdout, "xSQLTable::haveInvalidEntry():Enter\n");
    if (dbg) fflush(stdout);
-   pField->setFocus();
+//   pField->setFocus();
    errStr = "Invalid Entry in Field \"" + pField->label() + "\"";
-   QMessageBox::message("Error", errStr, "Ok");
+   xMessageBox::message("Error", errStr, "Ok");
    if (dbg) fprintf(stdout, "xSQLTable::haveInvalidEntry():Exit\n");
    if (dbg) fflush(stdout);
 }
