@@ -1,5 +1,5 @@
 /***************************************************************************
-**    xSocket.cpp  $Revision: 1.17 $ - $Name: V2-05 $ 
+**    xSocket.cpp  $Revision: 1.19 $ - $Name: V2-18 $ 
 **    Class to manipulate sockets
 **
 **    Copyright (C) 1996 Joseph Croft <jcroft@unicomp.net>
@@ -42,7 +42,8 @@ static int dbg = 0;
 static const char *pInitialResources[] =
 {
    "*ConnectTime: 60000",
-   "*AcceptTime: 300000"
+   "*AcceptTime: 300000",
+   NULL
 };
 
 xSocketTCP::xSocketTCP(xWidgetResInfo *pPRes, QObject *pParent, const char *pHost, 
@@ -69,16 +70,24 @@ xSocketTCP::xSocketTCP(xWidgetResInfo *pPRes, QObject *pParent, const char *pHos
    snr = NULL;
    sna = NULL;
    snc = NULL;
+   bBuf = NULL;
+   bPtr = NULL;
+   bCnt = 0;
+   bMode = FALSE;
    socketOff = FALSE;
+   deadSocket = FALSE;
    pTimer = new QTimer(this);
 
-   if (dbg) fprintf(stdout, "xSocketTCP::xSocketTCP.connect():Getting service name\n");
+   if (dbg) fprintf(stdout, "xSocketTCP::xSocketTCP.connect():Getting service name: |%s|, %d\n",
+                             pService, atoi(pService));
    if (dbg) fflush(stdout);
    memset((void *)&connAddr, '\0', sizeof(connAddr));
    if ((se = getservbyname(pService, "tcp")) != NULL)
       port = se->s_port;
    else if ((port = htons((u_short)atoi(pService))) == 0)
    {
+      if (dbg) fprintf(stdout, "xSocketTCP::xSocketTCP.connect():Invalid Service!\n");
+      if (dbg) fflush(stdout);
       err = xSocketTCP::ERROR_INVALIDSERVICE;
       return;
    }
@@ -252,8 +261,8 @@ xSocketTCP::~xSocketTCP()
       delete snr;
    }
    snr = NULL;
-   if (dbf)
-      fclose(dbf);
+//   if (dbf)
+//      fclose(dbf);
    if (pTimer)
       delete pTimer;
 }
@@ -264,6 +273,8 @@ void xSocketTCP::retryConnect(int sock)
 
    if (dbg) fprintf(stdout, "xSocketTCP::retryConnect(%d:%d):Enter\n", sock, fd);
    if (dbg) fflush(stdout);
+   if (deadSocket)
+      return;
    if ((n = fcntl(sock, F_GETFL, 0)) < 0)
       return;
    n |= FNDELAY;
@@ -411,10 +422,12 @@ void xSocketTCP::timeout()
 void xSocketTCP::readyRead(int sfd)
 {
    int n;
-   char buf[512];
+   char buf[16 * 1024];
 
    if (dbg > 3) fprintf(stdout, "xSocketTCP::readyRead(%d:%d):Enter\n", sfd, fd);
    if (dbg) fflush(stdout);
+   if (deadSocket)
+      return;
    if ((n = ::read(sfd, buf, sizeof(buf - 1))) < 0)
    {
       if (dbg) fprintf(stdout, "xSocketTCP::readyRead():Error Reading from Socket %d\n", sfd);
@@ -442,7 +455,8 @@ void xSocketTCP::readyRead(int sfd)
          close(fd);
          emit socketClosed();
          fd = -1;
-         delete this;
+         deadSocket = TRUE;
+//         delete this;
       }
    }
    else if (n > 0)
@@ -450,11 +464,13 @@ void xSocketTCP::readyRead(int sfd)
       if (dbg > 3) fprintf(stdout, "xSocketTCP::readyRead(%d):Read %d chars from socket\n", sfd, n);
       if (dbg) fflush(stdout);
       buf[n] = '\0';
-      if (dbf) fprintf(dbf, buf);
-      if (dbf) fflush(dbf);
+//      if (dbf) fprintf(dbf, buf);
+//      if (dbf) fflush(dbf);
       if (dbg > 3) fprintf(stdout, "xSocketTCP::readyRead():Emitin readFromSocket signal\n");
       if (dbg > 3) fflush(stdout);
       emit readFromSocket(buf);
+      xSocketBuffer sb = { buf, n};
+      emit readFromSocketBin(sb);
       if (dbg > 3) fprintf(stdout, "xSocketTCP::readyRead():Back from sending signal\n");
       if (dbg > 3) fflush(stdout);
    }
@@ -483,27 +499,31 @@ void xSocketTCP::readyRead(int sfd)
          if (dbg) fflush(stdout);
          emit socketClosed();
       }
-      delete this;
+      deadSocket = TRUE;
+//      delete this;
    }
    if (dbg > 3) fprintf(stdout, "xSocketTCP::readyRead(%d:%d):Exit\n", sfd, fd);
 }
 
 void xSocketTCP::readyWrite(int sfd)
 {
-   int n;
+   int n = 1;
    bool tf;
-   char buf[512];
 
-   if (dbg) fprintf(stdout, "xSocketTCP::readyWrite(%d:%d):Enter\n", sfd, fd);
-   if (dbg) fflush(stdout);
-   if ((n = writeBuffer.length()) > 0)
+   if (dbg > 3) fprintf(stdout, "xSocketTCP::readyWrite(%d:%d):Enter\n", sfd, fd);
+   if (dbg > 3) fflush(stdout);
+   if (deadSocket)
+      return;
+
+   if (!isBinary() && writeBuffer.length() > 0)
    {
       if (dbg) fprintf(stdout, "xSocketTCP::readyWrite(%d:%d):writing %d chars, |%s|, to socket\n", sfd, fd, n, (const char *)writeBuffer);
       if (dbg) fflush(stdout);
-      sprintf(buf, "Client>>|%s|\n", (const char *)writeBuffer);
-      if (dbf) fprintf(dbf, buf);
-      if (dbf) fflush(dbf);
-      if ((n = ::write(fd, (const char *)writeBuffer, n)) > 0)
+//      sprintf(buf, "Client>>|%s|\n", (const char *)writeBuffer);
+//      if (dbf) fprintf(dbf, buf);
+//      if (dbf) fflush(dbf);
+      if ((n = ::write(fd, (const char *)writeBuffer,
+                       writeBuffer.length())) > 0)
       {
          if (dbg) fprintf(stdout, "xSocketTCP::readyWrite():Wrote %d chars to socket\n", n);
          if (dbg) fprintf(stdout, "xSocketTCP::readyWrite():Removing string from buffer\n");
@@ -513,69 +533,105 @@ void xSocketTCP::readyWrite(int sfd)
          if (dbg) fprintf(stdout, "xSocketTCP::readyWrite():Chars removed\n");
          if (dbg) fflush(stdout);
       }
-      else if (n < 0)
+   }
+   else if (isBinary() == TRUE)
+   {
+      if (bCnt > 0)
       {
-         if (dbg) fprintf(stdout, "xSocketTCP::readyWrite():Error writing!\n");
-         if (dbg) fflush(stdout);
-         close(sfd);
-         if (sfd == fd)
+         if ((n = ::write(fd, bPtr, bCnt)) > 0)
          {
-            fd = -1;
-            writeBuffer = "";
-            connectFlag = FALSE;
-            emit socketClosed();
-            if (snw)
-            {
-               QObject::disconnect(snw, SIGNAL(activated(int)), this, SLOT(readyWrite(int)));
-               delete snw;
-            }
-            snw = NULL;
-            if (snr)
-            {
-               QObject::disconnect(snr, SIGNAL(activated(int)), this, SLOT(readyRead(int)));
-               delete snr;
-            }
-            snr = NULL;
-            delete this;
-         }
-      }
-      else
-      {
-         if (dbg) fprintf(stdout, "xSocketTCP::readyWrite(%d:%d):Write SOCKET CLOSED!\n", sfd, fd);
-         if (dbg) fflush(stdout);
-         close(sfd);
-         if (sfd == fd)
-         {
-            fd = -1;
-            writeBuffer = "";
-            connectFlag = FALSE;
-            emit socketClosed();
-            if (snw)
-            {
-               QObject::disconnect(snw, SIGNAL(activated(int)), this, SLOT(readyWrite(int)));
-               delete snw;
-            }
-            snw = NULL;
-            if (snr)
-            {
-               QObject::disconnect(snr, SIGNAL(activated(int)), this, SLOT(readyRead(int)));
-               delete snr;
-            }
-            snr = NULL;
-            delete this;
+            bCnt -= n;
+            bPtr += n;
          }
       }
    }
-   if (snw)
+
+   /*
+   ** Handle Closed Sockets and Socket Errors Accordingly
+   */
+   if (n < 0)
+   {
+      if (dbg) fprintf(stdout, "xSocketTCP::readyWrite(%d:%d):Error writing!\n",
+                               sfd, fd);
+      if (dbg) fflush(stdout);
+      snw->setEnabled(FALSE);
+      close(sfd);
+      if (sfd == fd)
+      {
+         fd = -1;
+         writeBuffer = "";
+         connectFlag = FALSE;
+         emit socketClosed();
+         if (snw)
+         {
+            QObject::disconnect(snw, SIGNAL(activated(int)), this, SLOT(readyWrite(int)));
+            delete snw;
+         }
+         snw = NULL;
+         if (snr)
+         {
+            QObject::disconnect(snr, SIGNAL(activated(int)), this, SLOT(readyRead(int)));
+            delete snr;
+         }
+         snr = NULL;
+         deadSocket = TRUE;
+//         delete this;
+      }
+   }
+   else if (n == 0)
+   {
+      if (dbg) fprintf(stdout, "xSocketTCP::readyWrite(%d:%d):Write SOCKET CLOSED!\n", sfd, fd);
+      if (dbg) fflush(stdout);
+      snw->setEnabled(FALSE);
+      close(sfd);
+      if (sfd == fd)
+      {
+         fd = -1;
+         writeBuffer = "";
+         connectFlag = FALSE;
+         emit socketClosed();
+         if (snw)
+         {
+            QObject::disconnect(snw, SIGNAL(activated(int)), this, SLOT(readyWrite(int)));
+            delete snw;
+         }
+         snw = NULL;
+         if (snr)
+         {
+            QObject::disconnect(snr, SIGNAL(activated(int)), this, SLOT(readyRead(int)));
+            delete snr;
+         }
+         snr = NULL;
+         deadSocket = TRUE;
+//         delete this;
+      }
+   }
+
+   /*
+   ** If there is still a socet notifier, turn it off if there is no data
+   ** left to send, either binary or string.
+   */
+   if (snw && !isBinary() && snw)
    {
       tf = !writeBuffer.isEmpty();
-      if (dbg) fprintf(stdout, "xSocketTCP::readyWrite():setting snw->Enabled to %d\n",
-                               tf);
+      if (dbg) fprintf(stdout, "xSocketTCP::readyWrite(%d:%d):setting snw->Enabled to %d\n",
+                               sfd, fd, tf);
       if (dbg) fflush(stdout);
       snw->setEnabled(tf);
    }
-   if (dbg) fprintf(stdout, "xSocketTCP::readyWrite(%d:%d):Done\n", sfd,fd);
-   if (dbg) fflush(stdout);
+   else if (snw && isBinary() && bCnt == 0)
+   {
+      if (bBuf != NULL)
+         delete bBuf;
+      bBuf = bPtr = NULL;
+      bCnt = 0;
+      bMode = FALSE;
+      snw->setEnabled(FALSE);
+      emit binaryWriteReady();
+   }
+
+   if (dbg > 3) fprintf(stdout, "xSocketTCP::readyWrite(%d:%d):Done\n", sfd,fd);
+   if (dbg > 3) fflush(stdout);
 }
 
 struct sockaddr_in xSocketTCP::socketName()
@@ -583,6 +639,10 @@ struct sockaddr_in xSocketTCP::socketName()
    struct sockaddr_in addr;
    int x;
 
+   memset(&addr, 0, sizeof(addr));
+   if (deadSocket)
+      return(addr);
+
    addr.sin_family = AF_INET;
    addr.sin_port = 0;
    addr.sin_addr.s_addr = htonl(INADDR_ANY);
@@ -602,27 +662,60 @@ void xSocketTCP::off()
    socketOff = TRUE;
 }
 
+void xSocketTCP::sendToSocket(xSocketBuffer sb)
+{
+   if (dbg > 3) fprintf(stdout, "xSocketTCP::sendToSocket(xSocketBuffer):Enter- %d, 0x%x, 0x%x\n",
+                             writeBuffer.isEmpty(), (int)bBuf, (int)snw);
+   if (dbg > 3) fflush(stdout);
+   if (deadSocket)
+      return;
+   if (writeBuffer.isEmpty() == TRUE && bBuf == NULL && snw != NULL)
+   {
+      if (dbg > 3) fprintf(stdout, "xSocketTCP::sendToSocket(xSocketBuffer):Sending %d bytes\n", sb.n);
+      if (dbg > 3) fflush(stdout);
+      bMode = TRUE;
+      bBuf = new char[sb.n];
+      bPtr = bBuf;
+      bCnt = sb.n;
+      memcpy(bBuf, sb.buf, sb.n);
+      snw->setEnabled(TRUE);
+   }
+   if (dbg > 3) fprintf(stdout, "xSocketTCP::sendToSocket(xSocketBuffer):Exit\n");
+   if (dbg > 3) fflush(stdout);
+}
+
 void xSocketTCP::sendToSocket(const char *pText)
 {
    bool tf;
+   int sfd = fd;
+
+   if (bMode || deadSocket)
+      return;
 
    if (!socketOff && snw != NULL && snr != NULL)
    {
+      tf = isBinary();
+      if (dbg) fprintf(stdout, "xSocketTCP::sendToSocket(%d:%d):bMode = %d\n",
+                               sfd, fd, tf);
+      if (dbg) fflush(stdout);
 //      if (connectFlag == TRUE && fd >= 0)
       if (fd >= 0)
       {
-         if (dbg) fprintf(stdout, "xSocketTCP::sendToSocket():Adding |%s| to writeBuffer\n", pText);
+         if (dbg) fprintf(stdout, "xSocketTCP::sendToSocket(%d:%d):Adding |%s| to writeBuffer\n",
+                          sfd, fd, pText);
          if (dbg) fflush(stdout);
          writeBuffer += pText;
       }
       tf = !writeBuffer.isEmpty();
-      if (dbg) fprintf(stdout, "xSocketTCP::sendToSocket():setting snw->Enabled to %d\n",
-                               tf);
+      if (dbg) fprintf(stdout, "xSocketTCP::sendToSocket(%d:%d):setting snw->Enabled to %d\n",
+                               sfd, fd, tf);
+      if (dbg) fflush(stdout);
       snw->setEnabled(tf);
    }
    else
    {
-      if (dbg) fprintf(stdout, "xSocketTCP::sendToSocket():Read or Write slot not connected!\n");
+      if (dbg) fprintf(stdout, "xSocketTCP::sendToSocket(%d:%d):Read or Write slot not connected!\n",
+                                sfd, fd);
       if (dbg) fflush(stdout);
    }
 }
@@ -631,6 +724,8 @@ void xSocketTCP::stopConnect()
 {
    int x = fd;
 
+   if (deadSocket)
+      return;
    if (dbg) fprintf(stdout, "xSocketTCP::stopConnect(%d):Enter\n", fd);
    if (dbg) fflush(stdout);
    pTimer->stop();
@@ -646,6 +741,7 @@ void xSocketTCP::stopConnect()
    snc = NULL;
    if (dbg) fprintf(stdout, "xSocketTCP::stopConnect(%d):Exit\n", x);
    if (dbg) fflush(stdout);
+   deadSocket = TRUE;
 //   delete this;
 }
 
@@ -697,9 +793,9 @@ int xSocketTCP::disconnectTCP()
    if (dbg) fflush(stdout);
    connectFlag = FALSE;
    fd = -1;
+   deadSocket = TRUE;
    if (dbg) fprintf(stdout, "xSocketTCP::disconnectTCP():Exit(%d)\n", x);
    if (dbg) fflush(stdout);
-   delete this;
    return(rv);
 }
 
