@@ -1,5 +1,5 @@
 /***************************************************************************
-**    xIrcConnect1.cpp  $Revision: 1.11 $ - $Name: V1-17B $ 
+**    xIrcConnect1.cpp  $Revision: 1.15 $ - $Name: V2-0 $ 
 **    Class for making the server connections
 **
 ** Copyright (C) 1995, 1996  Joseph Croft <jcroft@unicomp.net>  
@@ -28,23 +28,25 @@
 #include <arpa/inet.h>
 #include <netinet/in.h>
 #include <qapp.h>
-#include <qmsgbox.h>
 #include <qkeycode.h>
-#include <qmenubar.h>
 #include <qsize.h>
+#include <xApp.h>
 #include <xLineEditQuery.h>
+#include <xMessageBox.h>
 #include "xIrcChannelQuery.h"
+#include "xIrcMsgDispatch.h"
 #include "xIrcNickQuery.h"
 #include "xIrcDccQuery.h"
 #include "xIrcServerQuery.h"
 #include "xIrcErrorBox.h"
 #include "xIrcInviteBox.h"
+#include "xIrcIgnoreQuery.h"
 #include "xDefaults.h"
 #include "xIrcConnect.h"
 
 static int dbg = 0;
 
-extern QApplication *pApp;
+extern xApplication *pApp;
 extern xDefaults Defaults;
 extern xIrcNickQuery *NickQuery;
 extern xChannelQuery *ChanQuery;
@@ -52,6 +54,7 @@ extern xServerQuery *ServQuery;
 extern xLineEditQuery *QuitQuery;
 extern xIrcCommands ircResponses;
 extern QPixmap *AppPixMap;
+extern xIrcMsgDispatch Dispatcher;
 
 xIrcConnect::xIrcConnect(xWidgetResInfo *pPRes, QWidget *parent,
                          const char *name, WFlags iFlags,
@@ -63,18 +66,35 @@ xIrcConnect::xIrcConnect(xWidgetResInfo *pPRes, QWidget *parent,
    struct passwd *pPasswdEnt;
    char buf[80];
 
+   if (dbg) fprintf(stdout, "xIrcConnect::xIrcConnect():Enter\n");
+   if (dbg) fflush(stdout);
    wdtPrv = new xWidgetResInfo(pPRes);
+   if (dbg) fprintf(stdout, "xIrcConnect::xIrcConnect():Settingv colors\n");
+   if (dbg) fflush(stdout);
    setDefPallet(this, wdtRes);
+   if (dbg) fprintf(stdout, "xIrcConnect::xIrcConnect():Setting fonts\n");
+   if (dbg) fflush(stdout);
    setDefFont(this, wdtRes);
+   if (dbg) fprintf(stdout, "xIrcConnect::xIrcConnect():Setting Popup ResInfo\n");
+   if (dbg) fflush(stdout);
 
+   if (dbg) fprintf(stdout, "xIrcConnect::xIrcConnect():Initializing Variables\n");
+   if (dbg) fflush(stdout);
    iFlags = 0;
    resizeCnt = -2;
    quitFlag = FALSE;
    serverFlag = FALSE;
    banFlag = FALSE;
+   ignoreFlag = FALSE;
    pIrcMsgFrames = NULL;
 //   pSocket = new xIrcSocket(this);
+   if (dbg) fprintf(stdout, "xIrcConnect::xIrcConnect():Setting Socket to Null\n");
+   if (dbg) fflush(stdout);
    pSocket = NULL;
+   Dispatcher.setSocket(pSocket);
+
+   if (dbg) fprintf(stdout, "xIrcConnect::xIrcConnect():Creating Main Window\n");
+   if (dbg) fflush(stdout);
    pMainWin = new xMultiLineFrame(wdtRes, this, NULL, width, height, maxLines);
    if (AppPixMap != NULL)
       setIcon(*AppPixMap);
@@ -84,11 +104,71 @@ xIrcConnect::xIrcConnect(xWidgetResInfo *pPRes, QWidget *parent,
    realName = pPasswdEnt->pw_gecos;
    gethostname(buf, sizeof(buf));
    hostName = buf;
+
+   if (dbg) fprintf(stdout, "xIrcConnect::xIrcConnect():Creating SocketBox\n");
+   if (dbg) fflush(stdout);
    pSocketBox = new xSocketDialog(wdtPrv, NULL);
+
+   if (dbg) fprintf(stdout, "xIrcConnect::xIrcConnect():Creating BanBox\n");
+   if (dbg) fflush(stdout);
    pBanBox = new xIrcBanDialog(wdtPrv);
+   if (dbg) fprintf(stdout, "xIrcConnect::xIrcConnect():Creating NickAction\n");
+   if (dbg) fflush(stdout);
    pNickAction = NULL;
    pNickAction = new xIrcNickActionQuery(wdtPrv);
 
+   pIgnore = new xIrcIgnoreQuery(wdtPrv);
+   pNotify = new xIrcNotifyQuery(wdtPrv);
+   pNotify->shutDown();
+   pNotifyList = new xIrcNotifyTable(wdtPrv);
+
+   connect(pNotify, SIGNAL(updateList(xIrcPeopleList*)),
+           pNotifyList, SLOT(update(xIrcPeopleList*)));
+   pNotifyList->show();
+
+   pLabel = new xLabel(wdtRes, this);
+
+   xWidgetResInfo wdtTmp(wdtRes, QString("menu"), QString("Menu"));
+   xWidgetResInfo wdtPopTmp(&wdtTmp, QString("popup"), QString("Popup"));
+
+   pNickMenu = new QPopupMenu;
+   setDefFont(pNickMenu, &wdtPopTmp);
+   setDefPallet(pNickMenu, &wdtPopTmp);
+   pNickMenu->insertItem("Show Folks Online", this, SLOT(showNotifyList()));
+   pNickMenu->insertItem("Action", this, SLOT(showNickAction()));
+   pNickMenu->insertItem("Change Nick", this, SLOT(newNick()));
+   setDefFont(pNickMenu, &wdtPopTmp);
+   setDefPallet(pNickMenu, &wdtPopTmp);
+
+   pListMenu = new QPopupMenu;
+   setDefFont(pListMenu, &wdtPopTmp);
+   setDefPallet(pListMenu, &wdtPopTmp);
+   pListMenu->insertItem("Server List", this, SLOT(newServer()));
+   pListMenu->insertItem("Ignore List", this, SLOT(showIgnore()));
+   pListMenu->insertItem("Notify List", this, SLOT(showNotify()));
+   setDefFont(pListMenu, &wdtPopTmp);
+   setDefPallet(pListMenu, &wdtPopTmp);
+
+   pFileMenu = new QPopupMenu;
+   setDefFont(pFileMenu, &wdtPopTmp);
+   setDefPallet(pFileMenu, &wdtPopTmp);
+   pFileMenu->insertItem("Connect Server", this, SLOT(newServer()));
+   pFileMenu->insertItem("Open Channel", this, SLOT(newChannel()));
+   pFileMenu->insertSeparator();
+   pFileMenu->insertItem("Exit", this, SLOT(quitIrc()));
+   setDefFont(pFileMenu, &wdtPopTmp);
+   setDefPallet(pFileMenu, &wdtPopTmp);
+
+   pMenu = new QMenuBar(this);
+   setDefFont(pMenu, &wdtPopTmp);
+   setDefPallet(pMenu, &wdtPopTmp);
+   pMenu->insertItem("File", pFileMenu);
+   pMenu->insertItem("Nick", pNickMenu);
+   pMenu->insertItem("Lists", pListMenu);
+   setDefFont(pMenu, &wdtTmp);
+   setDefPallet(pMenu, &wdtTmp);
+
+/*
    pButtons = new xPshBtnFrame(wdtRes, this);
    pButtons->setFrameStyle(QFrame::Panel | QFrame::Raised);
    pButtons->setAlignment(xALIGN_Horz);
@@ -101,6 +181,7 @@ xIrcConnect::xIrcConnect(xWidgetResInfo *pPRes, QWidget *parent,
    pButtons->addButton("Your Nick", btnNick);
    pButtons->addButton("Quit", btnQuit);
    connect(pButtons, SIGNAL(clicked(int)), this, SLOT(buttonPressed(int)));
+*/
 
    if (dbg) fprintf(stdout, "xIrcConnect::xIrcConnect():Connecting xNickActionQuery Signals/slots\n");
    if (dbg) fflush(stdout);
@@ -108,11 +189,14 @@ xIrcConnect::xIrcConnect(xWidgetResInfo *pPRes, QWidget *parent,
           this, SLOT(nickActionHandler(xMultiLineTextSelection)));
    connect(pMainWin, SIGNAL(textSelected(xMultiLineTextSelection)),
            pNickAction, SLOT(wakeUp(xMultiLineTextSelection)));
+   connect(pNotifyList, SIGNAL(selected(const char*)),
+           pNickAction, SLOT(wakeUp(const char*)));
 
    connect(ServQuery, SIGNAL(msgToSocket(const char *)),
            this, SLOT(sendMsgToSocket(const char *)));
    connect(ChanQuery, SIGNAL(hasResult(int)),
            this, SLOT(gotChanBoxResult(int)));
+   pButtons = NULL;
 /*
    connect(pSocket, SIGNAL(socketClosed()),
            this, SLOT(socketClosed()));
@@ -128,8 +212,9 @@ xIrcConnect::xIrcConnect(xWidgetResInfo *pPRes, QWidget *parent,
            pSocket, SLOT(stopConnect()));
    connect(pSocketBox, SIGNAL(nextConnection()),
            pSocket, SLOT(tryNextConnection()));
-*/
    addWidget(pButtons);
+*/
+   addWidget(pLabel);
    addWidget(pMainWin);
    setMargins(0,0);
    setWidgetSpacing(0);
@@ -146,6 +231,8 @@ xIrcConnect::~xIrcConnect()
    if (dbg) fflush(stdout);
    if (pSocket)
       delete pSocket;
+   Dispatcher.setSocket(NULL);
+   pNotify->shutDown();
    if (dbg) fprintf(stdout, "xIrcConnect::~xIrcConnect():Deleting Buttons\n");
    if (dbg) fflush(stdout);
    if (pButtons)
@@ -162,9 +249,11 @@ xIrcConnect::~xIrcConnect()
       if (dbg) fflush(stdout);
       for (pM = pIrcMsgFrames; pM != NULL; pM = pM1)
       {
-         if (dbg) fprintf(stdout, "xIrcConnect::~xIrcConnect():Deleting Message Frame\n");
+         if (dbg) fprintf(stdout, "xIrcConnect::~xIrcConnect():Pointing to next Message Frame\n");
          if (dbg) fflush(stdout);
          pM1 = pM->next();
+         if (dbg) fprintf(stdout, "xIrcConnect::~xIrcConnect():Deleting Message Frame\n");
+         if (dbg) fflush(stdout);
          delete pM;
       }
    }
@@ -176,6 +265,29 @@ xIrcConnect::~xIrcConnect()
    if (dbg) fflush(stdout);
 }
 
+void xIrcConnect::showNickAction()
+{
+   pNickAction->show();
+}
+
+void xIrcConnect::showIgnore()
+{
+   pIgnore->show();
+}
+
+void xIrcConnect::showNotify()
+{
+   pNotify->show();
+}
+
+void xIrcConnect::showNotifyList()
+{
+   if (pNotifyList->isVisible() != TRUE)
+      pNotifyList->show();
+   else
+      pNotifyList->hide();
+}
+
 void xIrcConnect::buttonPressed(int btn) 
 {
    switch(btn)
@@ -292,6 +404,8 @@ void xIrcConnect::goodConnection(int sock)
          emit textOut(buf);
       }
    }
+   Dispatcher.setSocket(pSocket);
+   pNotify->startUp();
 }
 
 void xIrcConnect::failedConnection(int err)
@@ -331,9 +445,11 @@ void xIrcConnect::failedConnection(int err)
    if (dbg) fflush(stdout);
    sprintf(buf, "***\x02 Connection Failed: %s\n", strerror(err));
    pMainWin->pWin->putString(buf);
-//   QMessageBox::message("Error", buf);
+//   xMessageBox::message("Error", buf);
    delete pSocket;
    pSocket = NULL;
+   Dispatcher.setSocket(pSocket);
+   pNotify->shutDown();
 //   if (dbg) fprintf(stdout, "IrcConnect::failedConnection():Calling newServer\n");
 //   if (dbg) fflush(stdout);
 //   newServer();
@@ -386,6 +502,8 @@ void xIrcConnect::newServer()
                                   ServQuery->server(), ServQuery->port(),
                                   pSocketBox, SLOT(connStatus(int)),
                                   SLOT(connectMessage(const char *)), err);
+         Dispatcher.setSocket(NULL);
+         pNotify->shutDown();
          if (err == 0)
          {
             connect(pSocket, SIGNAL(socketClosed()),
@@ -427,17 +545,25 @@ void xIrcConnect::newServer()
             disconnect(pSocket, SIGNAL(connFailed(int)),      
                        this, SLOT(failedConnection(int)));
             pSocketBox->hide();
-            QMessageBox::message("Error", "Connection Failed");
+            xMessageBox::message("Error", "Connection Failed");
 */
             if (dbg) fprintf(stdout, "xIrcConnect::newServer():Failed!!!\n");
             if (dbg) fflush(stdout);
+            delete pSocket;
+            pSocket = NULL;
+            Dispatcher.setSocket(pSocket);
+            pNotify->shutDown();
             newServer();
          }
          if (dbg) fprintf(stdout, "xIrcConnect::newServer():Waiting connection\n");
          if (dbg) fflush(stdout);
       }
       else
+      {
          pSocket = NULL;
+         Dispatcher.setSocket(pSocket);
+         pNotify->shutDown();
+      }
    }
 }
 
@@ -455,7 +581,7 @@ void xIrcConnect::newNick()
          break;
       }
       else if (strlen(nickName) == 0)
-         QMessageBox::message("Error", "You must choose a NickName");
+         xMessageBox::message("Error", "You must choose a NickName");
       else
          break;
    }
@@ -477,8 +603,12 @@ void xIrcConnect::stopConnection()
    disconnect(pSocketBox, SIGNAL(stopConnection()),
               this, SLOT(stopConnection()));
    pSocket->stopConnect();
+   delete pSocket;
    pSocket = NULL;
+   Dispatcher.setSocket(pSocket);
+   pNotify->shutDown();
 }
+
 void xIrcConnect::socketClosed()
 {
       char buf[512];
@@ -512,7 +642,10 @@ void xIrcConnect::socketClosed()
       disconnect(pSocketBox, SIGNAL(nextConnection()),
               pSocket, SLOT(tryNextConnection()));
 */
+      delete pSocket;
       pSocket = NULL;
+      Dispatcher.setSocket(pSocket);
+      pNotify->shutDown();
       if (dbg) fprintf(stdout, "xIrcConnect::socketClosed():Signals disconnected\n");
       if (dbg) fflush(stdout);
       if (quitFlag)
@@ -539,7 +672,7 @@ void xIrcConnect::gotChanBoxResult(int result)
    if (dbg) fflush(stdout);
    if (pSocket == NULL)
    {
-      QMessageBox::message("Error", "Not Connected to a Server");
+      xMessageBox::message("Error", "Not Connected to a Server");
       return;
    }
 
@@ -567,7 +700,7 @@ void xIrcConnect::gotChanBoxResult(int result)
          }     
       }
       else
-         QMessageBox::message("Error", "Channel already opened");
+         xMessageBox::message("Error", "Channel already opened");
    }
    else if (result == xChannelQuery::DccChat)
    {
@@ -588,7 +721,7 @@ void xIrcConnect::gotChanBoxResult(int result)
          {
             sprintf(buf, "Error Accepting Connection from %s:%s",
                          ChanQuery->editText(), strerror(err));
-            QMessageBox::message("Error", buf);
+            xMessageBox::message("Error", buf);
             disconnect(pDccChatFrame, SIGNAL(initiateDCCChat(xIrcDccChatFrame*)),
                        this, SLOT(initiateDCCChat(xIrcDccChatFrame*)));
             delete pDccChatFrame;
@@ -615,7 +748,7 @@ void xIrcConnect::sendMsgToSocket(const char *pBuf)
 }
 void xIrcConnect::sendMessage(xIrcMessage *pMsg)
 {
-   emit msgOut(pMsg);
+   Dispatcher.dispatchMsg(NULL, NULL, pMsg);
 }
 
 void xIrcConnect::recvMessage(xIrcMessage *pMsg)
@@ -707,7 +840,7 @@ void xIrcConnect::gotErrorAck(int rspCode)
             break;
          }
          else
-            QMessageBox::message("Error", "You must choose a NickName");
+            xMessageBox::message("Error", "You must choose a NickName");
       }
       sprintf(buf, "NICK %s\n", NickQuery->text());
       emit textOut(buf);
@@ -745,16 +878,28 @@ void xIrcConnect::resizeEvent(QResizeEvent *pEvt)
       {
          if (dbg) fprintf(stdout, "xIrcConnect::resizeEvent():Resizing Terminal Frame - %d\n", resizeCnt);
          if (dbg) fflush(stdout);
+         sizeTerm.setHeight(sizeFrame.height() - pLabel->size().height());
+/*
          sizeTerm.setHeight(sizeFrame.height() - pButtons->size().height());
+*/
          pMainWin->resize(sizeTerm);
       }
 
+      s = pLabel->size();
+/*
       s = pButtons->size();
+*/
       s.setWidth(sizeTerm.width());
+      pLabel->resize(s);
+/*
       pButtons->resize(&s);
+*/
 
       sizeNewFrame = pMainWin->size();
+      sizeNewFrame.setHeight(sizeNewFrame.height() + pLabel->size().height());
+/*
       sizeNewFrame.setHeight(sizeNewFrame.height() + pButtons->size().height());
+*/
       if (sizeNewFrame != sizeFrame)
       {
          if (dbg) fprintf(stdout, "xIrcConnect::resizeEvent():Fittinging Frame - %d\n", resizeCnt);
@@ -831,7 +976,7 @@ void xIrcConnect::newServer()
             disconnect(pSocket, SIGNAL(connFailed(int)),      
                        this, SLOT(failedConnection(int)));
             pSocketBox->hide();
-            QMessageBox::message("Error", "Connection Failed");
+            xMessageBox::message("Error", "Connection Failed");
             if (dbg) fprintf(stdout, "xIrcConnect::newServer():Failed!!!\n");
             if (dbg) fflush(stdout);
             newServer();
