@@ -1,5 +1,5 @@
 /***************************************************************************
-**    xIrcConnect2.cpp  $Revision: 1.6 $ - $Name: V1-17B $ 
+**    xIrcConnect2.cpp  $Revision: 1.14 $ - $Name: V2-0 $ 
 **    Class for making the server connections Part 2
 **
 ** Copyright (C) 1995, 1996  Joseph Croft <jcroft@unicomp.net>  
@@ -22,20 +22,27 @@
 #include <pwd.h>
 #include <unistd.h>
 #include <stdlib.h>
+#include <fcntl.h>
 #include <ctype.h>
 #include <time.h>
+#include <sys/stat.h>
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <arpa/inet.h>
 #include <netinet/in.h>
 #include <qapp.h>
-#include <qmsgbox.h>
 #include <qkeycode.h>
 #include <qmenubar.h>
 #include <qsize.h>
+#include <qregexp.h>
+#include <xApp.h>
+#include <xFileDialog.h>
 #include <xLineEditQuery.h>
+#include <xMessageBox.h>
 #include "xIrcChannelQuery.h"
+#include "xIrcMsgDispatch.h"
 #include "xIrcNickQuery.h"
+#include "xIrcDccFile.h"
 #include "xIrcDccQuery.h"
 #include "xIrcServerQuery.h"
 #include "xIrcErrorBox.h"
@@ -45,13 +52,14 @@
 
 static int dbg = 0;
 
-extern QApplication *pApp;
+extern xApplication *pApp;
 extern xDefaults Defaults;
 extern xIrcNickQuery *NickQuery;
 extern xChannelQuery *ChanQuery;
 extern xServerQuery *ServQuery;
 extern xLineEditQuery *QuitQuery;
 extern xIrcCommands ircResponses;
+extern xIrcMsgDispatch Dispatcher;
    
 void xIrcConnect::initiateDCCChat(xIrcDccChatFrame *chatFrame)
 {
@@ -62,7 +70,7 @@ void xIrcConnect::initiateDCCChat(xIrcDccChatFrame *chatFrame)
    
    if (pSocket == NULL)
    {
-      QMessageBox::message("Error", "Not Connected to a Server");
+      xMessageBox::message("Error", "Not Connected to a Server");
       return;
    }
 
@@ -99,6 +107,7 @@ void xIrcConnect::dccChatHandler(xIrcMessage *pMsg)
 {
    xIrcMessageFrame *pMsgFrame;
    xIrcDccChatFrame *pDccChatFrame;
+//   xIrcDccFile *pDccFileFrame;
    char buf[256];
    int err;
    const char *cp;
@@ -123,43 +132,102 @@ void xIrcConnect::dccChatHandler(xIrcMessage *pMsg)
       if (dbg) fprintf(stdout, "xIrcConnect::dccChatHandler():Setting up DCC Chat to %s @ |%s|!\n", 
                                (const char *)pMsg->srcNick, cp);
       if (dbg) fflush(stdout);
-      if ((pDccChatFrame = new xIrcDccChatFrame(wdtPrv, NULL, pMsg->srcNick)) != NULL)
-      if ((err = pDccChatFrame->connectTo(cp)) == 0)
+      if (pMsg->pmsgTyp == ipmDCCChat)
       {
-         connect(pDccChatFrame, SIGNAL(textSelected(xMultiLineTextSelection)),
-                 pNickAction, SLOT(wakeUp(xMultiLineTextSelection)));
-         pDccChatFrame->show();
+         pDccChatFrame = new xIrcDccChatFrame(wdtPrv, NULL, pMsg->srcNick);
+         if (pDccChatFrame != NULL)
+         {
+            if ((err = pDccChatFrame->connectTo(cp)) == 0)
+            {
+               connect(pDccChatFrame, 
+                       SIGNAL(textSelected(xMultiLineTextSelection)),
+                       pNickAction, SLOT(wakeUp(xMultiLineTextSelection)));
+               pDccChatFrame->show();
+            }
+            else
+            {
+               sprintf(buf, "Error Making DCC Connection to %s:%s",
+                            (const char *)pMsg->srcNick, strerror(err));
+               xMessageBox::message("Error", buf);
+               delete pDccChatFrame;
+            }
+         }
       }
-      else
+/*
+      else if (pMsg->pmsgTyp == ipmDCCSend)
       {
-         sprintf(buf, "Error Making DCC Connection to %s:%s",
-                      (const char *)pMsg->srcNick, strerror(err));
-         QMessageBox::message("Error", buf);
-         delete pDccChatFrame;
+         int fd;
+         const char *cp;
+         QString file;
+         const char *pDir;
+
+         pDir = Resources->get(wdtRes, "dcc.dir", "DCC.Dir");
+         for (cp = pMsg->msgStr; *(++cp) != ' ';)
+            file += *cp;
+         QString s(xFileDialog::getSaveFileName(wdtRes, pDir, file));
+         if (!s.isEmpty())
+         {
+            if ((fd = open(s, O_RDWR | O_CREAT, S_IRWXU | S_IRGRP)) >= 0)
+            {
+               pDccFileFrame = new xIrcDccFile(wdtPrv, NULL, pMsg->srcNick);
+               if (pDccFileFrame != NULL)
+               {
+                  if ((err = pDccFileFrame->connectTo(cp, fd)) == 0)
+                     pDccFileFrame->show();
+                  else
+                  {
+                     sprintf(buf, "Error Making DCC Connection to %s:%s",
+                                  (const char *)pMsg->srcNick, strerror(err));
+                     xMessageBox::message("Error", buf);
+                     delete pDccFileFrame;
+                  }
+               }
+            }
+            else
+            {
+               sprintf(buf, "Error Opening file %s:%s",
+                            (const char *)s, strerror(errno));
+               xMessageBox::message("Error", buf);
+               delete pDccFileFrame;
+            }
+         }
       }
+*/
    }
 }
 
-void xIrcConnect::msgQryHandler(xIrcMessage *pMsg)
+void xIrcConnect::msgQryHandler(xIrcMsgQuery *pMsgQuery)
 {
    xIrcMessageFrame *pMsgFrame;
+   xIrcMessageList *pMsgList;
+   xIrcMessage *pMsg, *pMsg1;
    
    if (dbg) fprintf(stdout, "xIrcConnect::msgQryHandler():got response from query\n");
    if (dbg) fflush(stdout);
-   if (pMsg != NULL)
+//   if ((msgList = pMsgQuery->getList()) != NULL)
+   pMsgList = pMsgQuery->getList();
+   if (pMsgQuery->results() == QDialog::Accepted)
    {
       if (dbg) fprintf(stdout, "xIrcConnect::msgQryHandler():Creating new message frame\n");
       if (dbg) fflush(stdout);
+      pMsg = pMsgList->first();
+      pMsg1 = pMsg;
       if ((pMsgFrame = makeNewMsgFrame(NULL, pMsg->srcNick)) != NULL)
       {
          if (dbg) fprintf(stdout, "xIrcConnect::msgQryHandler():Showing message frame\n");
          if (dbg) fflush(stdout);
          pMsgFrame->show();
-         if (dbg) fprintf(stdout, "xIrcConnect::msgQryHandler():Sending message to frame\n");
-         if (dbg) fflush(stdout);
-         pMsgFrame->procServerMsg(pMsg);
+         for (pMsg = pMsgList->first(); pMsg != NULL; pMsg = pMsgList->next())
+         {
+            if (dbg) fprintf(stdout, "xIrcConnect::msgQryHandler():Sending message to frame\n");
+            if (dbg) fflush(stdout);
+            pMsgFrame->procServerMsg(pMsg);
+         }
       }
    }
+   if (dbg) fprintf(stdout, "xIrcConnect::msgQryHandler():Removing Query\n");
+   if (dbg) fflush(stdout);
+   msgQueryList.remove(pMsgQuery);
    if (dbg) fprintf(stdout, "xIrcConnect::msgQryHandler():Exit()\n");
    if (dbg) fflush(stdout);
 }
@@ -189,6 +257,8 @@ void xIrcConnect::gotResponse(xIrcMessage *pMsg)
    if (dbg) fflush(stdout);
 
    pSocketBox->hide();
+   if (Dispatcher.proccessResponse(pMsg) == TRUE)
+      return;
    if (isMsg(pMsg->rspCode, "NICK"))
    {
       if (dbg) fprintf(stdout, "xIrcConnect::gotResponse():A Nick is Changing!\n");
@@ -213,43 +283,13 @@ void xIrcConnect::gotResponse(xIrcMessage *pMsg)
       }
    }
 
-   if (banFlag == TRUE && pMsg->rspCode == 352)
+/*
+   if ((pMsg->rspCode == 352 || pMsg->rspCode == 315) &&
+       pNotify->gotNotification(pMsg) == TRUE)
    {
-      pBanBox->setNick(banNick);
-      pBanBox->setChan(banChan);
-      pBanBox->setMask(buildBanMask(pMsg));
-      if ((x = pBanBox->exec()) != xIrcBanDialog::Rejected)
-      {
-         msg.rspCode = ircResponses.code("MODE");
-         msg.dstStr = pBanBox->chan();
-         msg.dstStr += (x == xIrcBanDialog::UnBan) ? " -b " : " +b ";
-         msg.dstStr += pBanBox->mask();
-         msg.msgStr = "";
-         sprintf(str, "\x02*** %sanning from %s: %s\n",
-                      (x == xIrcBanDialog::UnBan) ? "Unb" : "B",
-                      (const char *)pBanBox->chan(),
-                      (const char *)pBanBox->nick());
-         pMainWin->pWin->putString(str);
-         emit msgOut(&msg);
-         banFlag = FALSE;
-         if (x == xIrcBanDialog::Kick)
-         {
-            msg.rspCode = ircResponses.code("KICK");
-            msg.dstStr = pBanBox->chan();
-            msg.dstStr += " ";
-            msg.dstStr += pBanBox->nick();
-            msg.msgStr = pBanBox->text();
-            emit msgOut(&msg);
-         }
-      }
-      return;
-   }   
-   else if (banFlag == TRUE && pMsg->rspCode == 315)
-   {
-      banFlag = FALSE;
       return;
    }
-
+*/
    if (isMsg(pMsg->rspCode, "INVITE"))
    {
       if (dbg) fprintf(stdout, "xIrcConnect::gotResponse():Got invitation!\n");
@@ -260,9 +300,27 @@ void xIrcConnect::gotResponse(xIrcMessage *pMsg)
       pIB->show();
       return;
    }
-            
+
+   if (pIgnore->list()->matches(pMsg))
+   {
+      xIrcPeopleEntry *p;
+      if ((p = pIgnore->list()->entry(pMsg)) != NULL)
+      {
+         if (p->flag() != 0)
+         {
+            showResponse(pMsg);
+            return;
+         }
+      }
+   }
+
    for (x = 0, pMsgFrame = pIrcMsgFrames; pMsgFrame; pMsgFrame = pMsgFrame->next())
    {
+      QRegExp regexp( " .*" );
+      QString tempName((char*)pMsgFrame->name());
+      tempName.replace( regexp, "");
+      pMsgFrame->setName((const char *)tempName);
+
       if (dbg) fprintf(stdout, "xIrcConnect::gotResponse():testing window |%s|\n", (char *)pMsgFrame->name());
       if (dbg) fflush(stdout);
       if (strlen(pMsgFrame->name()) > 0 && pMsgFrame->procServerMsg(pMsg))
@@ -299,14 +357,20 @@ void xIrcConnect::gotResponse(xIrcMessage *pMsg)
          if (dbg) fflush(stdout);
          if (!doSpecialMessage(pMsg))
          {
-            if (dbg) fprintf(stdout, "xIrcConnect::gotResponse():Starting New message queryQuery\n");
-            if (dbg) fflush(stdout);
-            if ((pMsgQry = new xIrcMsgQuery(wdtPrv)) != NULL)
+            if ((pMsgQry = msgQueryList.find(pMsg)) != NULL)
+               pMsgQry->add(pMsg);
+            else
             {
-               connect(pMsgQry, SIGNAL(done(xIrcMessage *)), 
-                       this, SLOT(msgQryHandler(xIrcMessage *)));
-               pMsgQry->setupQuery(pMsg);
-               pMsgQry->show();
+               if (dbg) fprintf(stdout, "xIrcConnect::gotResponse():Starting New message queryQuery\n");
+               if (dbg) fflush(stdout);
+               if ((pMsgQry = new xIrcMsgQuery(wdtPrv)) != NULL)
+               {
+                  msgQueryList.append(pMsgQry);
+                  connect(pMsgQry, SIGNAL(done(xIrcMsgQuery *)), 
+                          this, SLOT(msgQryHandler(xIrcMsgQuery *)));
+                  pMsgQry->add(pMsg);
+                  pMsgQry->show();
+               }
             }
          }
       }
@@ -417,6 +481,24 @@ bool xIrcConnect::doSpecialMessage(xIrcMessage *pMsg)
          break;
 
       case ipmDCCSend:
+/*
+         if (dbg) fprintf(stdout, "xIrcConnect::doSpecial():Got DCC Send Request!\n");
+         if (dbg) fflush(stdout);
+         if ((pMsgQry = new xIrcDccQuery(wdtPrv)) != NULL)
+         {
+            QString file("Send: ");
+            const char *cp;
+
+            for (cp = pMsg->msgStr; *(++cp) != ' ';)
+               file += *cp;
+            connect(pMsgQry, SIGNAL(done(xIrcMessage *)), this, SLOT(dccChatHandler(xIrcMessage *)));
+            pMsgQry->setupQuery(file, pMsg);
+         }
+         if (dbg) fprintf(stdout, "xIrcConnect::doSpecial():Waiting Query Response!\n");
+         if (dbg) fflush(stdout);
+         rv = TRUE;
+         break;
+*/
       case ipmDCC:
          if (dbg) fprintf(stdout, "xIrcConnect::doSpecial():Got DCC Request!\n");
          if (dbg) fflush(stdout);
@@ -463,7 +545,7 @@ bool xIrcConnect::doSpecialMessage(xIrcMessage *pMsg)
             msg.rspCode = ircResponses.code("NOTICE");
             msg.dstStr = pMsg->srcNick;
             msg.msgStr = "\x01";
-            msg.msgStr += "VERSION xIrc Version 1.15 Running on Linux";
+            msg.msgStr += "VERSION xIrc $Name: V2-0 $";
             msg.msgStr += "\x01";
             emit msgOut(&msg);
          }
@@ -501,7 +583,8 @@ bool xIrcConnect::doSpecialMessage(xIrcMessage *pMsg)
             if ((cp = Defaults.get("SOURCEINFO")) != NULL)
                msg.msgStr += cp;
             else
-               msg.msgStr += "sunsite.unc.edu:/pub/linux/X11/xapps/networked:xIrc-X.X.tar.gz xIrc-X.X.lsm";
+               msg.msgStr += "sunsite.unc.edu:/pub/linux/X11/system/network/chat/xIrc-X.X.tar.gz xIrc-X.X.lsm or ";
+               msg.msgStr += "http:www.dfw.net/~croftj";
             msg.msgStr += "\x01";
             emit msgOut(&msg);
             msg.rspCode = ircResponses.code("NOTICE");
