@@ -15,22 +15,27 @@
 ** along with this program; if not, write to the Free Software
 ** Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
-#ifndef "_xIRCMSGDISPATCH_H"
-#define "_xIRCMSGDISPATCH_H"
+#ifndef XIRCMSGDISPATCH_H
+#define XIRCMSGDISPATCH_H
 
+#include <qobject.h>
+#include "xIrcSocket.h"
 #include "xIrcMsgDispatchEntry.h"
 
-class xIrcDispatch
+class xIrcMsgDispatch
 {
-   Q_OBJECT
-
 public:
    xIrcMsgDispatch();
    ~xIrcMsgDispatch();
 
-   void dispatchCommand(QWidget *pWidget, char *pSlot, xIrcMessage *pMsg);
+   void dispatchMsg(QObject *pObj, const char *pSlot, xIrcMessage *pMsg);
    bool proccessResponse(xIrcMessage *pMsg);
+   bool outstanding(xIrcMessage *pMsg);
+   void setSocket(xIrcSocket *s);
 
 private:
-   QList<xIrcMsgDispatchEntry> dspList;
+   xIrcMsgDispatchList  dspList;
+   xIrcSocket           *pSocket;
 };
+
+#endif
