@@ -17,29 +17,45 @@
 ** along with this program; if not, write to the Free Software
 ** Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
-#ifndef "_xIRCMSGDISPATCHENTRY_H"
-#define "_xIRCMSGDISPATCHENTRY_H"
+#ifndef XIRCMSGDISPATCHENTRY_H
+#define XIRCMSGDISPATCHENTRY_H
 
+#include <qobject.h>
 #include "xIrcSocket.h"
 
-class xIrcMsgDispatchEntry
+class xIrcMsgDispatchEntry : public QObject
 {
    Q_OBJECT
 
 public:
-   xIrcMsgDispatchEntry(QWidget *p_Widget, const char *p_Slot,
-                         xIrcMessage *p_Msg, bool &accepted);
+   xIrcMsgDispatchEntry(QObject *pObj, const char *p_Slot,
+                         xIrcMessage *pMsg, int &accepted);
    ~xIrcMsgDispatchEntry();
    bool is(xIrcMessage *pMsg);
    bool dispatchResponse(xIrcMessage *pMsg);
+   xIrcMessage *message() { return(&msg); };
+   void setSent(bool f) { sentFlag = f; };
+   bool sent() { return(sentFlag); };
+   bool dispatch() { return(pObject != NULL); };
 
 signals:
-   void gotResponse(pMsg);
+   void gotResponse(xIrcMessage *pMsg);
 
 private:
+   bool        sentFlag;
    QString     slot;
    xIrcMessage msg;
-   QWidget     *pWidget;
+   QObject     *pObject;
    int         *pResponseList;
 };
 
+typedef QListT<xIrcMsgDispatchEntry>            xIrcMsgDispatchListBase;
+typedef QListIteratorT<xIrcMsgDispatchEntry>    xIrcMsgDispatchListIterator;
+
+class xIrcMsgDispatchList : public xIrcMsgDispatchListBase
+{
+public:
+   xIrcMsgDispatchList() { setAutoDelete(TRUE); };
+};
+
+#endif
