@@ -1,5 +1,5 @@
 /***************************************************************************
-**    xIrcMsgFrame1.cpp  $Revision: 1.17 $ - $Name: V1-17B $ 
+**    xIrcMsgFrame1.cpp  $Revision: 1.19 $ - $Name: V2-0 $ 
 **    Class to handle chatting w/ a person or channel
 **
 ** Copyright (C) 1995, 1996  Joseph Croft <jcroft@unicomp.net>  
@@ -26,8 +26,9 @@
 #include <qkeycode.h>
 #include "xDefaults.h"
 #include "xResources.h"
-#include "xIrcNickQuery.h"
+#include "xIrcMsgDispatch.h"
 #include "xIrcMsgFrame.h"
+#include "xIrcNickQuery.h"
 
 static int dbg = 0;
 
@@ -35,10 +36,10 @@ extern xIrcCommands ircResponses;
 extern xIrcNickQuery *NickQuery;
 extern xDefaults Defaults;
 extern QPixmap *AppPixMap;
+extern xIrcMsgDispatch Dispatcher;
 
 static const char *pInitialResources[] =
 {
-   "*MsgChat.Input.Font.Family: Fixed",
    NULL
 };
 
@@ -226,7 +227,8 @@ void xIrcMessageFrame::closeFrame()
       msg.rspCode = ircResponses.code("PART");
       msg.dstStr = cp;
       msg.msgStr = "";
-      emit ircMessageOut(&msg);
+      Dispatcher.dispatchMsg(this, SLOT(ircRespMessageIn(xIrcMessage*)), &msg);
+//      emit ircMessageOut(&msg);
       if (dbg) fprintf(stdout, "xIrcmessageFrame::xIrcMessageFrame():Disconnecting Timer\n");
       if (dbg) fflush(stdout);
       disconnect(pNickUpdateTimer, SIGNAL(timeout()), this, SLOT(nickTime()));
@@ -280,7 +282,8 @@ void xIrcMessageFrame::doPing()
    msg.msgStr += "\x01";
    sprintf(buf1, "*** Ping command sent to %s\n", (const char *)msg.dstStr);
    pMsgFrame->pWin->putString(buf1);
-   emit ircMessageOut(&msg);
+   Dispatcher.dispatchMsg(this, SLOT(ircRespMessageIn(xIrcMessage*)), &msg);
+//   emit ircMessageOut(&msg);
 }
 
 void xIrcMessageFrame::clearLine() 
@@ -301,7 +304,8 @@ void xIrcMessageFrame::nickTime()
       msg.rspCode = ircResponses.code("NAMES");
       msg.dstStr = name();
       msg.msgStr = "";
-      emit ircMessageOut(&msg);
+      Dispatcher.dispatchMsg(this, SLOT(ircRespMessageIn(xIrcMessage*)), &msg);
+//      emit ircMessageOut(&msg);
       if (dbg) fprintf(stdout, "xIrcmessageFrame::nickTime():Exit\n");
       if (dbg) fflush(stdout);
    }
@@ -319,7 +323,8 @@ void xIrcMessageFrame::nickPurgeTime()
       msg.rspCode = ircResponses.code("NAMES");
       msg.dstStr = name();
       msg.msgStr = "";
-      emit ircMessageOut(&msg);
+      Dispatcher.dispatchMsg(this, SLOT(ircRespMessageIn(xIrcMessage*)), &msg);
+//      emit ircMessageOut(&msg);
       if (dbg) fprintf(stdout, "xIrcmessageFrame::nickTime():Exit\n");
       if (dbg) fflush(stdout);
    }
@@ -352,7 +357,8 @@ void xIrcMessageFrame::gotKeyboardInput()
          msg.msgStr = buf;
          if (dbg) fprintf(stdout, "xIrcMessageFrame::gotKeyboardInput():Sending input\n");
          if (dbg) fflush(stdout);
-         emit ircMessageOut(&msg);
+         Dispatcher.dispatchMsg(this, SLOT(ircRespMessageIn(xIrcMessage*)), &msg);
+//         emit ircMessageOut(&msg);
          if (dbg) fprintf(stdout, "xIrcMessageFrame::gotKeyboardInput():Putting it on the screen!\n");
          if (dbg) fflush(stdout);
          sprintf(buf, "-> %s\n", pEdit->text());
