@@ -1,5 +1,5 @@
 /***************************************************************************
-**    xIrcMsgFrame2.cpp  $Revision: 1.19 $ - $Name: V1-17B $ 
+**    xIrcMsgFrame2.cpp  $Revision: 1.20 $ - $Name: V2-0 $ 
 **    Class to handle chatting w/ a person or channel
 **
 ** Copyright (C) 1995, 1996  Joseph Croft <jcroft@unicomp.net>  
@@ -29,6 +29,7 @@
 #include "xDefaults.h"
 #include "xIrcNickQuery.h"
 #include "xLineEditQuery.h"
+#include "xIrcMsgDispatch.h"
 #include "xIrcMsgFrame.h"
 #include "xIrcChannelQuery.h"
 
@@ -39,6 +40,7 @@ extern xIrcCommands ircResponses;
 extern xChannelQuery *ChanQuery;
 extern xIrcNickQuery *NickQuery;
 extern xLineEditQuery *KickQuery;
+extern xIrcMsgDispatch Dispatcher;
 
 bool xIrcMessageFrame::isMsg(int cmd, char *pStr)
 { 
@@ -93,6 +95,24 @@ void xIrcMessageFrame::ircRespMessageIn(xIrcMessage *pMsg)
    if (pMsg->rspCode == 366)
       return;
       
+   if (pMsg->rspCode == 353)
+   {
+      QString tmpDst, tmpName;
+      const char *cp;
+
+      if (dbg) fprintf(stdout, "xIrcMessageFrame::ircRespMessageIn():Testing Names response\n");
+      if (dbg) fflush(stdout);
+      for (cp = pMsg->dstStr, tmpDst = ""; *cp; cp++)
+         tmpDst += toupper(*cp);
+      for (cp = (char *)name(), tmpName = ""; *cp; cp++)
+         tmpName += toupper(*cp);
+      if (strcmp(tmpName, tmpDst) == 0 && pNicks && pNicks->isVisible())
+      {
+         pNicks->setNicks(pMsg->msgStr);
+         return;
+      }
+   }
+
    pMsg->msgStr.stripWhiteSpace();
    if (dbg) fprintf(stdout, "xIrcMessageFrame::ircRespMessageIn():Done simplifying WS\n");
    if (dbg) fflush(stdout);
@@ -150,11 +170,13 @@ void xIrcMessageFrame::ircRespMessageIn(xIrcMessage *pMsg)
          msg.dstStr = "";
          msg.msgStr = NickQuery->text();
          msg.msgStr += "_";
-         emit ircMessageOut(&msg);
+         Dispatcher.dispatchMsg(this, SLOT(ircRespMessageIn(xIrcMessage*)), &msg);
+//         emit ircMessageOut(&msg);
          msg.rspCode = ircResponses.code("JOIN");
          msg.dstStr = name();
          msg.msgStr = "";
-         emit ircMessageOut(&msg);
+         Dispatcher.dispatchMsg(this, SLOT(ircRespMessageIn(xIrcMessage*)), &msg);
+//         emit ircMessageOut(&msg);
          if ((cp = (char *)Defaults.get("KICKED_YOU_RESPONSE")) != NULL)
          {
             msg.rspCode = ircResponses.code("PRIVMSG");
@@ -162,12 +184,14 @@ void xIrcMessageFrame::ircRespMessageIn(xIrcMessage *pMsg)
             msg.msgStr = pMsg->srcNick;
             msg.msgStr = ", ";
             msg.msgStr += cp;
-            emit ircMessageOut(&msg);
+            Dispatcher.dispatchMsg(this, SLOT(ircRespMessageIn(xIrcMessage*)), &msg);
+//            emit ircMessageOut(&msg);
          }
          msg.rspCode = ircResponses.code("NICK");
          msg.dstStr = "";
          msg.msgStr = NickQuery->text();
-         emit ircMessageOut(&msg);
+         Dispatcher.dispatchMsg(this, SLOT(ircRespMessageIn(xIrcMessage*)), &msg);
+//         emit ircMessageOut(&msg);
       }
       else
       {
@@ -184,7 +208,8 @@ void xIrcMessageFrame::ircRespMessageIn(xIrcMessage *pMsg)
             msg.rspCode = ircResponses.code("PRIVMSG");
             msg.dstStr = str;
             msg.msgStr = cp;
-            emit ircMessageOut(&msg);
+            Dispatcher.dispatchMsg(this, SLOT(ircRespMessageIn(xIrcMessage*)), &msg);
+//            emit ircMessageOut(&msg);
          }
       }
    }
@@ -264,7 +289,8 @@ void xIrcMessageFrame::doSpecial(xIrcMessage *pMsg)
          msg.msgStr += "PING ";
          msg.msgStr += str;
          msg.msgStr += "\x01";
-         emit ircMessageOut(&msg);
+         Dispatcher.dispatchMsg(this, SLOT(ircRespMessageIn(xIrcMessage*)), &msg);
+//         emit ircMessageOut(&msg);
       }
    }
    else if (pMsg->pmsgTyp == ipmVersion)
@@ -636,7 +662,8 @@ void xIrcMessageFrame::procCommand(char *pStr)
       pMsgFrame->pWin->putString(buf);
       return;
    }
-   emit ircMessageOut(&msg);
+   Dispatcher.dispatchMsg(this, SLOT(ircRespMessageIn(xIrcMessage*)), &msg);
+//   emit ircMessageOut(&msg);
 }
 
 void xIrcMessageFrame::nickButtonPressed(int iBtn)
@@ -720,7 +747,8 @@ void xIrcMessageFrame::nickButtonPressed(int iBtn)
          default:
             return;
       }      
-      emit ircMessageOut(&msg);
+      Dispatcher.dispatchMsg(this, SLOT(ircRespMessageIn(xIrcMessage*)), &msg);
+//      emit ircMessageOut(&msg);
    }
    else
    {
